
# Slot: value_specification_constant


Grouping for metamodel slots that constrain the a slot value to equal a specified constant

URI: [linkml:value_specification_constant](https://w3id.org/linkml/value_specification_constant)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children

 *  equals_expression
 *  equals_number
 *  equals_string
 *  maximum_cardinality
 *  minimum_cardinality
 *  value_presence

## Used by

